/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <project.h>
#include "led.h"
#include "led.c"
#include "i2c.h"
#include "i2c.c"



uint8 capsenseNotify = 0;
uint16 capacitance, capacitanceOld, rawCount;
uint8 capBuffer[BUFFER_SIZE], rawBuffer[BUFFER_SIZE];

void updateData(){
    
    if(CyBle_GetState() != CYBLE_STATE_CONNECTED)
    return;
    
    CYBLE_GATTS_HANDLE_VALUE_NTF_T tempHandle, tempHandle1;
    tempHandle.attrHandle = CYBLE_CAPSENSE_CAPACITANCE_CHAR_HANDLE;
    tempHandle.value.val = (uint8 *) &capacitance;
    tempHandle.value.len = 2;
    CyBle_GattsWriteAttributeValue(&tempHandle, 0, &cyBle_connHandle, CYBLE_GATT_DB_LOCALLY_INITIATED);
    
    tempHandle1.attrHandle = CYBLE_CAPSENSE_RAWCOUNT_CHAR_HANDLE;
    tempHandle1.value.val = (uint8 *) &rawCount;
    tempHandle1.value.len = 2;
    CyBle_GattsWriteAttributeValue(&tempHandle1, 0, &cyBle_connHandle, CYBLE_GATT_DB_LOCALLY_INITIATED);
    
    /* SEND NOTIFICATION IF ENABLED AND CAPACITANCE VALUE HAS CHANGED */
    if(capsenseNotify && (capacitance != capacitanceOld)){
        
       CyBle_GattsNotification(cyBle_connHandle, &tempHandle); 
       capacitanceOld = capacitance; 
    }
}
    
    
    


void BleCallBack(uint32 event, void* eventParam){
    CYBLE_GATTS_WRITE_REQ_PARAM_T *wrReqParam;
    
    switch(event){
        /* if there is a disconnect or the stack is just turned on*/
            case CYBLE_EVT_STACK_ON:
            case CYBLE_EVT_GAP_DEVICE_DISCONNECTED:
                capsenseNotify = 0;
                CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST);
                ledOn();
            break;
        /* when a connection is made, update server data */
            case CYBLE_EVT_GATT_CONNECT_IND:
                updateData();
                ledBlink();
            break;
                
        /*handle a write request */
            case CYBLE_EVT_GATTS_WRITE_REQ:
                wrReqParam = (CYBLE_GATTS_WRITE_REQ_PARAM_T *) eventParam;
            /* request to update Capsense Notification */
                if(wrReqParam -> handleValPair.attrHandle == CYBLE_CAPSENSE_CAPACITANCE_CAPSENSECCCD_DESC_HANDLE){
                    CyBle_GattsWriteAttributeValue(&wrReqParam -> handleValPair, 0, &cyBle_connHandle, CYBLE_GATT_DB_PEER_INITIATED);
                    capsenseNotify = wrReqParam -> handleValPair.value.val[0] & 0x01;
                    CyBle_GattsWriteRsp(cyBle_connHandle);
                }
                break;
                
                default:
                break;
    }
    
}
        

int main (void)
{
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */

    CyGlobalIntEnable;
    
    /*start the EZI2C component*/
	i2c_Start();
    
    /*set the data buffer to be written to*/
    i2cBufferSetup(capBuffer, rawBuffer);
    
	/*start the bluetooth event handler*/	  
    CyBle_Start(BleCallBack);
    
    for(;;)
    {
        if((i2c_EzI2CGetActivity() != i2c_EZI2C_STATUS_BUSY) && capBuffer[1] != 0){
            capacitance = 0xFFFF;
            rawCount = 0xFFFF;
            for(uint8 i = 0; i < BUFFER_SIZE; ++i){
                /*fill capacitance and rawCount variables with data received from measurement*/
                capacitance = capacitance & capBuffer[i];
                rawCount = rawCount & rawBuffer[i];
                if(i < 1){
                capacitance = capacitance << 8;
                rawCount = rawCount << 8;
                }
            }
            updateData();
            
        }
        CyBle_ProcessEvents();
        CyBle_EnterLPM(CYBLE_BLESS_DEEPSLEEP);
        }
}

/* [] END OF FILE */
